
.. _datasets:

===============================================================================
Sample Datasets
===============================================================================

.. note:
	The number of sample datasets included with trikit is continually growing. 
	If you'd like to contribute a dataset, please contact ``james.triveri@gmail.com``.
	
	

In addition to stand-alone datasets, trikit is distributed along with the 
|LRDB|__. More information on accessing and working with the database can be 
found :ref:`here<lrdb>`.







.. |LRDB| replace:: CAS Loss Reserving Database
__ https://www.casact.org/research/index.cfm?fa=loss_reserves_data

